@@ -7,6 +7,7 @@ import (
 	"github.com/abiosoft/colima/cli"
 	"github.com/abiosoft/colima/config"
 	"github.com/abiosoft/colima/environment"
+	"github.com/abiosoft/colima/util/debutil"
 )
 
 // Name is container runtime name.
@@ -130,6 +131,16 @@ func (d dockerRuntime) Dependencies() []string {
 }
 
 func (d dockerRuntime) Version(ctx context.Context) string {
-	version, _ := d.host.RunOutput("docker", "version", "--format", `client: v{{.Client.Version}}{{printf "\n"}}server: v{{.Server.Version}}`)
+	version, _ := d.host.RunOutput("docker", "--context", config.CurrentProfile().ID, "version", "--format", `client: v{{.Client.Version}}{{printf "\n"}}server: v{{.Server.Version}}`)
 	return version
 }
+
+func (d *dockerRuntime) Update(ctx context.Context) (bool, error) {
+	packages := []string{
+		"docker-ce",
+		"docker-ce-cli",
+		"containerd.io",
+	}
+
+	return debutil.UpdateRuntime(ctx, d.guest, d, packages...)
+}
