@@ -16,6 +16,7 @@ import (
 	"github.com/abiosoft/colima/environment/vm/lima/limaconfig"
 	"github.com/abiosoft/colima/environment/vm/lima/limautil"
 	"github.com/abiosoft/colima/util"
+	"github.com/abiosoft/colima/util/downloader"
 	"github.com/abiosoft/colima/util/osutil"
 	"github.com/abiosoft/colima/util/yamlutil"
 	"github.com/sirupsen/logrus"
@@ -31,9 +32,8 @@ func New(host environment.HostActions) environment.VM {
 	var envs []string
 	envHome := limautil.EnvLimaHome + "=" + limaHome
 	envLimaInstance := envLimaInstance + "=" + config.CurrentProfile().ID
-	envSSHForward := "LIMA_SSH_PORT_FORWARDER=true"
 	envBinary := osutil.EnvColimaBinary + "=" + osutil.Executable()
-	envs = append(envs, envHome, envLimaInstance, envSSHForward, envBinary)
+	envs = append(envs, envHome, envLimaInstance, envBinary)
 
 	// consider making this truly flexible to support other VMs
 	return &limaVM{
@@ -274,11 +274,34 @@ func (l limaVM) Arch() environment.Arch {
 func (l *limaVM) downloadDiskImage(ctx context.Context, conf config.Config) error {
 	log := l.Logger(ctx)
 
+	// use a user specified disk image
+	if conf.DiskImage != "" {
+		if _, err := os.Stat(conf.DiskImage); err != nil {
+			return fmt.Errorf("invalid disk image: %w", err)
+		}
+
+		image, err := limautil.Image(l.limaConf.Arch, conf.Runtime)
+		if err != nil {
+			return fmt.Errorf("error getting disk image details: %w", err)
+		}
+
+		sha := downloader.SHA{Size: 512, Digest: image.Digest}
+		if err := sha.ValidateFile(l.host, conf.DiskImage); err != nil {
+			return fmt.Errorf("disk image must be downloaded from '%s', hash failure: %w", image.Location, err)
+		}
+
+		image.Location = conf.DiskImage
+		l.limaConf.Images = []limaconfig.File{image}
+		return nil
+	}
+
+	// use a previously cached image
 	if image, ok := limautil.ImageCached(l.limaConf.Arch, conf.Runtime); ok {
 		l.limaConf.Images = []limaconfig.File{image}
 		return nil
 	}
 
+	// download image
 	log.Infoln("downloading disk image ...")
 	image, err := limautil.DownloadImage(l.limaConf.Arch, conf.Runtime)
 	if err != nil {
@@ -358,9 +381,11 @@ func (l *limaVM) addPostStartActions(a *cli.ActiveCommandChain, conf config.Conf
 	a.Add(func() error {
 		if !l.limaConf.Rosetta.Enabled {
 			// use binfmt when rosetta is disabled and emulation is disabled i.e. host arch
-			if arch := environment.HostArch(); arch == environment.Arch(conf.Arch).Value() {
-				if err := core.SetupBinfmt(l.host, l, environment.Arch(conf.Arch)); err != nil {
-					logrus.Warn(fmt.Errorf("unable to enable qemu %s emulation: %w", arch, err))
+			if l.conf.Binfmt {
+				if arch := environment.HostArch(); arch == environment.Arch(conf.Arch).Value() {
+					if err := core.SetupBinfmt(l.host, l, environment.Arch(conf.Arch)); err != nil {
+						logrus.Warn(fmt.Errorf("unable to enable qemu %s emulation: %w", arch, err))
+					}
 				}
 			}
 
