@@ -51,7 +51,7 @@ func newConf(ctx context.Context, conf config.Config) (l limaconfig.Config, err
 	}
 
 	if conf.CPUType != "" && conf.CPUType != "host" {
-		l.CPUType = map[environment.Arch]string{
+		l.VMOpts.QEMU.CPUType = map[environment.Arch]string{
 			l.Arch: conf.CPUType,
 		}
 	}
@@ -258,6 +258,14 @@ func newConf(ctx context.Context, conf config.Config) (l limaconfig.Config, err
 				HostPortRange:     [2]int{1, 65535},
 				Proto:             limaconfig.TCP,
 			},
+			limaconfig.PortForward{
+				GuestIPMustBeZero: true,
+				GuestIP:           net.ParseIP("0.0.0.0"),
+				GuestPortRange:    [2]int{1, 65535},
+				HostIP:            net.ParseIP("0.0.0.0"),
+				HostPortRange:     [2]int{1, 65535},
+				Proto:             limaconfig.UDP,
+			},
 		)
 		// bind 127.0.0.1
 		l.PortForwards = append(l.PortForwards,
@@ -268,6 +276,13 @@ func newConf(ctx context.Context, conf config.Config) (l limaconfig.Config, err
 				HostPortRange:  [2]int{1, 65535},
 				Proto:          limaconfig.TCP,
 			},
+			limaconfig.PortForward{
+				GuestIP:        net.ParseIP("127.0.0.1"),
+				GuestPortRange: [2]int{1, 65535},
+				HostIP:         net.ParseIP("127.0.0.1"),
+				HostPortRange:  [2]int{1, 65535},
+				Proto:          limaconfig.UDP,
+			},
 		)
 
 		// bind all host addresses when network address is not enabled
